# TestPlanChangedFieldsViewModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | [**StringTestPlanChangedFieldViewModel**](StringTestPlanChangedFieldViewModel.md) |  | [optional] 
**description** | [**StringTestPlanChangedFieldViewModel**](StringTestPlanChangedFieldViewModel.md) |  | [optional] 
**product_name** | [**StringTestPlanChangedFieldViewModel**](StringTestPlanChangedFieldViewModel.md) |  | [optional] 
**build** | [**StringTestPlanChangedFieldViewModel**](StringTestPlanChangedFieldViewModel.md) |  | [optional] 
**period** | [**PeriodViewModelTestPlanChangedFieldViewModel**](PeriodViewModelTestPlanChangedFieldViewModel.md) |  | [optional] 
**status** | [**StringTestPlanChangedFieldViewModel**](StringTestPlanChangedFieldViewModel.md) |  | [optional] 
**tags** | [**StringArrayTestPlanChangedFieldViewModel**](StringArrayTestPlanChangedFieldViewModel.md) |  | [optional] 
**test_suite** | [**TestSuiteChangeViewModelTestPlanChangedFieldViewModel**](TestSuiteChangeViewModelTestPlanChangedFieldViewModel.md) |  | [optional] 
**test_points** | [**TestPointChangeViewModelTestPlanChangedFieldViewModel**](TestPointChangeViewModelTestPlanChangedFieldViewModel.md) |  | [optional] 
**test_results** | [**TestResultChangeViewModelTestPlanChangedFieldViewModel**](TestResultChangeViewModelTestPlanChangedFieldViewModel.md) |  | [optional] 
**locking** | [**BooleanTestPlanChangedFieldViewModel**](BooleanTestPlanChangedFieldViewModel.md) |  | [optional] 
**has_automatic_duration_timer** | [**BooleanNullableTestPlanChangedFieldViewModel**](BooleanNullableTestPlanChangedFieldViewModel.md) |  | [optional] 
**attributes** | [**{str: (CustomAttributeChangeModel,)}, none_type**](CustomAttributeChangeModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


